@@ -4,7 +4,7 @@
 modname = 'expense'
 distname = 'cubicweb-expense'
 
-numversion = (0, 6, 3)
+numversion = (0, 7, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -19,9 +19,10 @@ classifiers = [
            'Programming Language :: JavaScript',
 ]
 
-__depends__ = {'cubicweb': '>= 3.9.0',
-               'cubicweb-addressbook': None}
-
+__depends__ = {'cubicweb': '>= 3.15.0',
+               'cubicweb-addressbook': None,
+               'cubicweb-file': None,
+               }
 
 # packaging ###
 
